from typing import List

from django.db.models import Field, Model


class ModelMeta(object):

    def __init__(self, instance: Model) -> None:
        self.options = instance._meta

    @staticmethod
    def is_related_field(field: Field):
        return field.one_to_many or field.one_to_one or field.many_to_many and field.related_model._meta.managed

    @property
    def related_fields(self) -> List[Field]:
        return [f for f in self.options.get_fields() if ModelMeta.is_related_field(f)]

    @property
    def editable_fields(self) -> List[Field]:
        return [f for f in self.options.fields if f.editable]

    @property
    def model_name(self) -> str:
        return self.options.model.__name__



from setuptools import find_packages, setup

try:
    import pypandoc
    long_description = pypandoc.convert('README.md', 'rst')
except ImportError:
    long_description = open('README.md').read()

setup(
    name='django-super-deduper',
    description='Utilities for deduping Django model instances',
    url='https://github.com/mighty-justice/django-super-deduper',
    long_description=long_description,
    version='0.0.7',
    classifiers=[
        'Framework :: Django :: 1.11',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.6',
    ],

    packages=find_packages(exclude=['tests']),
    include_package_data=True,

    install_requires=['django>=1.11'],

    test_suite='tests',
)
